@@ -1,28 +1,28 @@
 module Full where
 
 
--- Used modules from the console-program package.
-import           System.Console.Command  (Commands,Tree(Node),Command(..),execute,showUsage,io)
+import           System.Console.Command
+  (
+    Commands,Tree(Node),Command,command,withOption,withNonOption,io
+  )
+import           System.Console.Program (single,showUsage)
 import qualified System.Console.Argument as Argument
 
--- Standard tree type, used to build the tree of commands.
-import Data.Tree (Tree(Node))
-
 
 main :: IO ()
-main = execute defaults myCommands
+main = single myCommands
 
-myCommands :: Commands
+myCommands :: Commands IO
 myCommands = Node
-  (Command "count" "A program for counting" . io $ putStrLn "No command given; try \"count help\".")
+  (command "count" "A program for counting" . io $ putStrLn "No command given; try \"count help\".")
   [
     Node countUp []
   , Node countDown []
   , Node help []
   ]
 
-countUp,countDown,help :: Command
-countUp = Command
+countUp,countDown,help :: Command IO
+countUp = command
   {
     name        = "up"
   , description = "Count up"
@@ -30,16 +30,24 @@ countUp = Command
       then putStrLn "Counting quietly!"
       else mapM_ print [1 ..]
   }
-countDown = Command
+countDown = command
   {
     name        = "down"
   , description = "Count down from INT."
   , action      = withNonOption Argument.natural $ \ upperBound -> io $ mapM_ print [upperBound, pred upperBound .. 1]
   }
-help = Command "help" "Show usage info" $ io (showUsage myCommands)
+help = command "help" "Show usage info" $ io (showUsage myCommands)
 
-verboseOpt :: Option
-verboseOpt = Argument.option Verbosity   ['v'] ["verbose"    ] verbosity        "Specify the verbosity of the program; "
+
+-- Custom data type to describe a verbosity level.
+data Verbosity
+  = Quiet
+  | Normal
+  | Verbose
+  deriving (Eq)
+
+verboseOpt :: Argument.Option Verbosity
+verboseOpt = Argument.option ['v'] ["verbose"] verbosity Normal "Specify the verbosity of the program."
 
 verbosity :: Argument.Type Verbosity
 verbosity = Argument.Type
@@ -49,6 +57,6 @@ verbosity = Argument.Type
       "normal"  -> Right Normal
       "quiet"   -> Right Quiet
       s         -> Left $ "The argument " ++ show s ++ " could not be recognised as a verbosity."
-  , Argument.name         = "verbosity"
+  , Argument.name         = "VERBOSITY"
   , Argument.defaultValue = Just Verbose
   }
