@@ -41,13 +41,8 @@ data Type a
   , name         :: String
     -- ^ A name for this type of option argument (for usage info).
   , defaultValue :: Maybe a
-    -- ^ The default value, when the option occurs without option argument.
+    -- ^ The default value when the option occurs without option argument.
     -- @Nothing@ means that an argument is required for this type of option.
-    -- 
-    -- Note that this may be different from the corresponding value in the default
-    -- configuration (the first argument of 'System.Console.Command.execute');
-    -- the latter is what you get when this option does not occur at all in the
-    -- configuration file or command line.
   }
 
 instance Functor Type where
@@ -62,7 +57,7 @@ option
   :: [Char]     -- ^ List of short option characters.
   -> [String]   -- ^ List of long option strings.
   -> Type a     -- ^ Type of option argument.
-  -> a          -- ^ Default value.
+  -> a          -- ^ Default value when the option is not specified by the user.
   -> String     -- ^ Description.
   -> Option a   -- ^ The resulting option description.
 option short long t def description = let
